@@ -1,4 +1,5 @@
 import uuid
+from datatime import datetime
 import sqlalchemy.types as types
 from sqlalchemy import Column, ForeignKey, String, DateTime
 from flask_sqlalchemy import SQLAlchemy as _SQLAlchemy, BaseQuery, Model as SAModel
@@ -72,7 +73,7 @@ class ModelUUID(SAModel):
 
     @declared_attr
     def created_at(cls):        
-        return Column(db.DateTime, default=datetime.now, nullable=False, index=True)
+        return Column(DateTime, default=datetime.now, nullable=False, index=True)
 
     @declared_attr.cascading
     def __mapper_args__(cls):
